import { ChangeDetectorRef, OnDestroy } from "@angular/core";
import { SchemaFormPropertyOptions } from "@smallstack/form-shared";
import { TranslationStore } from "@smallstack/i18n-components";
import { SmallstackTypeSchema } from "@smallstack/typesystem";
import { BehaviorSubject, Observable, Subscription } from "rxjs";
import { FormOptions } from "../../interfaces/form-options";
import { InputWidgetValidationError } from "../../interfaces/form-validation";
import { FormService } from "../../services/form.service";
import * as i0 from "@angular/core";
/** @deprecated use FormOptions */
export type SchemaFormOptions = FormOptions;
/**
 * This is the base class for all form based widgets (aka input widgets)
 */
export declare class SchemaFormBase<T = any> implements OnDestroy {
    protected widgetSpecificOptions$: BehaviorSubject<FormOptions>;
    options$: Observable<FormOptions>;
    set options(options: FormOptions);
    private path$;
    formService: FormService;
    set path(path: string);
    get path(): string;
    validationErrors$: Observable<InputWidgetValidationError[]>;
    hasValidationErrors$: Observable<boolean>;
    validationErrorText$: Observable<string>;
    /**The schema for the current input widget */
    schema$: Observable<SmallstackTypeSchema>;
    value$: Observable<T>;
    translationStore: TranslationStore;
    /** This subscription will be closed automatically onDestroy */
    protected subscription: Subscription;
    protected cdr: ChangeDetectorRef;
    constructor();
    ngOnDestroy(): void;
    /** sets the value for the path of the current widget */
    setValue(val: T): void;
    /** gets a snapshot of the value for the current widget */
    getValue(): T;
    /** Manually triggers the validation for this input widget */
    validate(): Promise<void>;
    /** Triggers the validation for this input widget if options.validateOn === "onBlur" */
    validateOnBlur(): Promise<void>;
    /** Triggers the validation for this input widget if options.validateOn === "onBlur" */
    validateOnChange(): Promise<void>;
    /** Use with caution! This will change the schema of the current input widget */
    overrideSchema(newSchema: SchemaFormPropertyOptions): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SchemaFormBase<any>, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<SchemaFormBase<any>, never, never, { "options": { "alias": "options"; "required": false; }; "path": { "alias": "path"; "required": false; }; }, {}, never, never, false, never>;
}
